@@ -4,6 +4,9 @@ class Voice(enum.Enum):
     ANNA = 1
     JULIA = 2
     VLADIMIR = 3
+    DASHA = 4
+    ASEL = 5
+    CAROL = 6
 
 
 class PlaybackProfile(enum.Enum):
